import matplotlib.pyplot as plt
import matplotlib as mpl#Normalisation des valeurs
import matplotlib.patches as mpatches#pour les carrés
import matplotlib.colorbar as cbar#barres de couleurs
import pandas as pd #lecture des fichiers csv
import numpy as np
from mpl_toolkits.axes_grid1 import make_axes_locatable#positionner les barres de couleurs

#Extraction des données du fichier .csv :
donnees=pd.read_csv("periodic-table.csv", delimiter=';', skiprows=1)
symbole=donnees["Symbol"]
ligne=donnees["ligne"]
Z=donnees["Atomic Number"]
colonne=donnees["colonne"]

"""
Les données atomiques sont à choisir parmi :
Electronegativity
Atomic Radius
Ion Radius
Ionization Energy
Electron Affinity
Melting Point
Boiling Point
Density
Van Del Waals Radius

Les colormaps sont à choisir parmi les séquentiels :
'Greys', 'Purples', 'Blues', 'Greens', 'Oranges', 'Reds',
'YlOrBr', 'YlOrRd', 'OrRd', 'PuRd', 'RdPu', 'BuPu',
'GnBu', 'PuBu', 'YlGnBu', 'PuBuGn', 'BuGn', 'YlGn'
"""

a=3#espace horizontal
b=3#espace vertical
#############################################
# FONCTION :
def numeroscolonnes():#numérote les colonnes en haut
    for i in np.arange(1, 19):
        plt.text(a*(i-0.2), -0.4, "%s"%(i), fontsize=8, color='gray')


#############################################

plt.rcParams["font.family"] = "Ubuntu"#ou autre police installée
#paramètres du graphique
fig=plt.figure(figsize=(7,6), tight_layout=True)
"""
Attention, en modifiant les dimensions (figsize, et valeurs des paramètres a et b, les tailles des polices
devront sans doute être réajustées.
"""
plt.title("Densité dans le tableau périodique", fontsize=16)

ax1=plt.subplot(111)
ax1.set_aspect('equal')

plt.xlabel(r"Densité ($kg\cdot L^{-1}$)")
plt.xticks([])
plt.yticks([])
#plt.axis('off')#retire le cadre du graphe
plt.ylim(-12*b, 1)

#gamme de couleurs choisie (colormap) :
cmap=plt.get_cmap('GnBu')
critereCouleur=donnees["Density"]#choix de la grandeur
#normalisation de la gamme de valeurs :
norm = mpl.colors.Normalize(vmin=min(critereCouleur),vmax=max(critereCouleur)) 

#tracé des cases :
for i in range(len(donnees)):
    plt.text(a*colonne[i], -b/2-b*ligne[i], symbole[i], fontsize=10, va='bottom', ha='center')#symbole
#    plt.text(a*colonne[i], -b/2-b*(ligne[i]+0.3),int(Z[i]), fontsize=6, ha='center')#écriture N° atomique
    plt.scatter(a*colonne[i], -b*ligne[i], alpha=0.0)
    ax1.add_artist(mpatches.Rectangle((-a*0.5+a*colonne[i], -b*ligne[i]), a, -b, color=cmap(norm(critereCouleur[i]))))

numeroscolonnes()

#tracé de la barre de couleurs :
divider = make_axes_locatable(ax1)
cax = divider.append_axes('bottom', size='8%', pad=0.3)
cb=cbar.ColorbarBase(cax, cmap=cmap, norm=norm, orientation='horizontal')

#----------------------------------------------------------------------------------------

fig.savefig("TableauPeriodiqueDensite.png", dpi=400)
plt.show()
